@@ -83,7 +83,7 @@ void Rcovmaker(double *sigma2, double *tau2eta, double *tau2theta, double *r, in
 void productmaker (double b[], int nb,double d[], double CholA[], double *bAinvb, double *bAinvd, double *dAinvd)
 {
 	char myL='L',myN='N';
-	int info=0, KD=nb, N=nb, LD=nb+1, LDB=nb, LDA=nb, one=1, i=0;
+	int info=0, N=nb, LDB=nb, LDA=nb, one=1, i=0;
 	double bstar[nb],dstar[nb],bb=0,dd=0,bd=0;
 
 for (i=0;i<nb;i++)
@@ -92,7 +92,7 @@ for (i=0;i<nb;i++)
 	dstar[i]=d[i];
 	}
 
-/*F77_CALL(dpbtrf)(&myL, &N, &KD , Chol, &LD,&info);/* Now Chol is Cholesky factor of A */
+/*F77_CALL(dpbtrf)(&myL, &N, &KD , Chol, &LD,&info); Now Chol is Cholesky factor of A */
 F77_CALL(dtrtrs)(&myL, &myN, &myN, &N, &one, CholA, &LDA,  bstar,&LDB, &info); /* Now bstar is inverse of Chol times b */
 F77_CALL(dtrtrs)(&myL, &myN, &myN, &N, &one, CholA, &LDA,  dstar,&LDB, &info); /* Now dstar is inverse of Chol times b */
 
@@ -528,7 +528,7 @@ void yreorder(double y[], int nrowy, int ncoly, double repno[], int nrepno, doub
 {
 	/* for noi=1 or noj=1 it won't work*/
 double repnosum[ntypeno],tresult[nrowy*ncoly], irowstart1=1,irowstart2=1;
-int i,j, startfill=0;
+int i, startfill=0;
 matsum (repno, nrepno, typeno, ntypeno, repnosum);
 
 for (i=0;i<(noi-1);i++)
@@ -647,31 +647,13 @@ void Rlogmarg0datavsAL (double *y, int *nrowy, int *ncoly, double *repno , int *
 logmarg0datavsAL (y, *nrowy, *ncoly, repno ,*nrepno, typeno, *ntypeno, theta,result);
 }
 
-/*
-void logmarg1dataG (double y[], int nrowy, int ncoly, double repno[] , int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
-{
-double sigma2,tau2eta, tau2theta, mu, ybar[ntypeno*ncoly],css[ntypeno*ncoly], newrepno[ntypeno];
-sigma2=exp(theta[0]);
-tau2eta=exp(theta[1]);
-tau2theta=exp(theta[2]); 
-mu=theta[3];
-p=1/(1+exp(-theta[4])); they are useless
-matsum(repno, nrepno, typeno, ntypeno, newrepno) ;
-cssofmatrix (y, (nrowy*ncoly), newrepno, ntypeno, ybar, css);
-logmarg1tmG(sigma2, tau2eta, tau2theta, mu, ybar, css, (ntypeno*ncoly ) , newrepno , ntypeno, result);
-}
-
-
-/*void matsum (double X[],int nX, double N[], int nN, double *result)
-void covmaker(double sigma2, double tau2eta, double tau2theta, double r[], int nr, double *Cov)
-void dmvnorm(double X[], int nX, double Mu[], double Sigma[],double *logdensity)*/
 
 void logmarg1vectorG(double y[], int ny, double repno[] , 
 int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
 double sigma2,tau2eta, tau2theta, mu, logdensity[1], submean[ny],subcov[ny*ny],
-	subrepno[nrepno],rtsum[ntypeno],sumrtsum,sumtypeno=0,suby[ny];
-int t,v,i,counter=0;
+	subrepno[nrepno],rtsum[ntypeno],sumrtsum=0,sumtypeno=0,suby[ny];
+int t,i;
 sigma2=exp(theta[0]);
 tau2eta=exp(theta[1]);
 tau2theta=exp(theta[2]); 
@@ -679,7 +661,6 @@ mu=theta[3];
 matsum(repno,nrepno,typeno,ntypeno,rtsum);
 for (t=0;t<ntypeno;t++)
 	{
-	counter=0;
 	for (i=sumtypeno;i<(sumtypeno+typeno[t]);i++){subrepno[(int)(i-sumtypeno)]=repno[i];}
 	for (i=0;i<rtsum[t];i++){submean[i]=mu;}
 	covmaker(sigma2,tau2eta,tau2theta,subrepno,typeno[t],subcov);
@@ -775,8 +756,8 @@ void logmarg1dataAL(double y[], int nrowy,int ncoly, double repno[] ,
 int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
 double logdetA,sigma2,tau2eta,logdensity[1], subrepno[nrepno],rtsum[ntypeno],sumrtsum=0,
-	sumtypeno=0,suby[nrowy],tresult[ntypeno*ncoly],sum,A[nrowy*nrowy];
-int t,m,i,counter=0,s;
+	sumtypeno=0,suby[nrowy],tresult[ntypeno*ncoly],A[nrowy*nrowy];
+int t,m,i,counter=0;
 sigma2=exp(theta[0]);
 tau2eta=exp(theta[1]);
 matsum(repno,nrepno,typeno,ntypeno,rtsum);
@@ -826,7 +807,7 @@ logmarg1dataG(y, *nrowy, *ncoly, repno , *nrepno, typeno, *ntypeno, theta,result
 
 void logmarg1datavsG (double y[], int nrowy, int ncoly, double repno[] , int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
-double sigma2,tau2eta, tau2theta, mu, ybar[ntypeno*ncoly],css[ntypeno*ncoly], newrepno[ntypeno],p,l1[ntypeno*ncoly],l0[ntypeno*ncoly] ;
+double  p,l1[ntypeno*ncoly],l0[ntypeno*ncoly] ;
 int i;
 p=1/(1+exp(-theta[4]));
 logmarg1dataG (y, nrowy, ncoly, repno , nrepno, typeno, ntypeno, theta,l1);
@@ -859,13 +840,9 @@ logmarg0datavsG (y, *nrowy, *ncoly, repno , *nrepno, typeno, *ntypeno, theta,res
 
 void logmarg1datavsAL (double y[], int nrowy, int ncoly, double repno[] , int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
-double sigma2,tau2eta, tau2thetaL,tau2thetaR, mu, ybar[ntypeno*ncoly],css[ntypeno*ncoly], newrepno[ntypeno],p,l1[ntypeno*ncoly],l0[ntypeno*ncoly] ;
+double p,l1[ntypeno*ncoly],l0[ntypeno*ncoly] ;
 int i;
-sigma2=exp(theta[0]);
-tau2eta=exp(theta[1]);
-tau2thetaL=exp(theta[2]); 
-tau2thetaR=exp(theta[3]); 
-mu=theta[4];
+
 p=1/(1+exp(-theta[5]));
 logmarg1dataAL (y, nrowy, ncoly, repno , nrepno, typeno, ntypeno, theta,l1);
 logmarg0datavsAL (y, nrowy, ncoly, repno , nrepno, typeno, ntypeno, theta,l0);
@@ -906,7 +883,7 @@ for (i=0; i<(ncoly*ntypeno); i++)
 
 void logmargdataG (double y[], int nrowy, int ncoly, double repno[] , int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
-double l0[ntypeno*ncoly], l1[ntypeno*ncoly],p, suml=0 ;
+double l0[ntypeno*ncoly], l1[ntypeno*ncoly],p;
 int i;
 p=1/(1+exp(-theta[4]));
 logmarg0dataG (y, nrowy, ncoly, repno , nrepno, typeno, ntypeno, theta, l0);
@@ -998,7 +975,7 @@ logmargdataG (y, *nrowy, *ncoly, repno, *nrepno, typeno, *ntypeno, theta, result
 
 void logmargdataAL (double y[], int nrowy, int ncoly, double repno[] , int nrepno, double typeno[], int ntypeno, double theta[],double  *result)
 {
-double l0[ntypeno*ncoly], l1[ntypeno*ncoly],p, suml=0 ;
+double l0[ntypeno*ncoly], l1[ntypeno*ncoly],p ;
 int i;
 p=1/(1+exp(-theta[5]));
 logmarg0dataAL (y, nrowy, ncoly, repno , nrepno, typeno, ntypeno, theta, l0);
@@ -1312,7 +1289,7 @@ int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno ;
 /*initialization*/
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -1354,7 +1331,7 @@ int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno ;
 /*initialization*/
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -1439,7 +1416,7 @@ matsum (repno, nrepno, typeno, ntypeno, repnosum);
 
 			int k, ijsize=(asint(repnosum[i-1]+repnosum[j-1])*ncoly);
 			double yij[ijsize ],combinedtypeno[]={1},combinedrepno[]={(repnosum[i-1]+repnosum[j-1])}, sumlij=0;
-			double sumlminusij=0,yminusij[ncoly*nrowy-ijsize],sumlijseparate=0, newsuml;
+			double sumlijseparate=0, newsuml;
 			sumof2rows (l0, ntypeno,ncoly ,i,j,l0ij);
 			select2individofy ( y, nrowy, ncoly, repno, nrepno, typeno, ntypeno, i, j, yij);
 			logmarg1dataG (yij,asint(repnosum[i-1]+repnosum[j-1]) , ncoly, combinedrepno, 1, combinedtypeno, 1, theta, l1ij);
@@ -1471,7 +1448,7 @@ for (i=1; i<=ntypeno;i++)
 			R_CheckUserInterrupt();
 			ijsize=(asint(repnosum[i-1]+repnosum[j-1])*ncoly);
 			combinedrepno[0]=(repnosum[i-1]+repnosum[j-1]);
-			sumlij=0;sumlminusij=0;sumlijseparate=0;
+			sumlij=0;sumlijseparate=0;
 			double yij[ijsize];
 /*			double yminusij[ncoly*nrowy-ijsize];*/
 			sumof2rows (l0, ntypeno,ncoly ,i,j,l0ij);
@@ -1515,7 +1492,7 @@ double typeno[], int ntypeno, double lvs0[], double sumlvs0[], double lvs1[], do
 double *minvalue, double  *minindex)
 	{
 int i=1,j=2; 
-double repnosum[ntypeno],l1ij[ncoly],l0ij[ncoly],p,lijseparate[2*ncoly],newtypeno[ntypeno],newldirich[1],q;
+double repnosum[ntypeno],l1ij[ncoly],l0ij[ncoly],p,newtypeno[ntypeno],newldirich[1],q;
 p=1/(1+exp(-theta[4]));
 q=1/(1+exp(-theta[5]));
 matsum (repno, nrepno, typeno, ntypeno, repnosum);
@@ -1627,7 +1604,7 @@ double typeno[], int ntypeno, double lvs0[], double sumlvs0[], double lvs1[], do
 double *minvalue, double  *minindex)
 	{
 int i=1,j=2; 
-double repnosum[ntypeno],l1ij[ncoly],l0ij[ncoly],p,lijseparate[2*ncoly],newtypeno[ntypeno],newldirich[1],q;
+double repnosum[ntypeno],l1ij[ncoly],l0ij[ncoly],p,newtypeno[ntypeno],newldirich[1],q;
 p=1/(1+exp(-theta[5]));
 q=1/(1+exp(-theta[6]));
 matsum (repno, nrepno, typeno, ntypeno, repnosum);
@@ -1746,7 +1723,7 @@ matsum (repno, nrepno, typeno, ntypeno, repnosum);
 
 			int k, ijsize=(asint(repnosum[i-1]+repnosum[j-1])*ncoly);
 			double yij[ijsize ],combinedtypeno[]={1},combinedrepno[]={(repnosum[i-1]+repnosum[j-1])}, sumlij=0;
-			double sumlminusij=0,yminusij[ncoly*nrowy-ijsize],sumlijseparate=0, newsuml;
+			double sumlijseparate=0, newsuml;
 			sumof2rows (l0, ntypeno,ncoly ,i,j,l0ij);
 			select2individofy ( y, nrowy, ncoly, repno, nrepno, typeno, ntypeno, i, j, yij);
 			logmarg1dataAL (yij,asint(repnosum[i-1]+repnosum[j-1]) , ncoly, combinedrepno, 1, combinedtypeno, 1, theta, l1ij);
@@ -1778,9 +1755,8 @@ for (i=1; i<=ntypeno;i++)
 			R_CheckUserInterrupt();
 			ijsize=(asint(repnosum[i-1]+repnosum[j-1])*ncoly);
 			combinedrepno[0]=(repnosum[i-1]+repnosum[j-1]);
-			sumlij=0;sumlminusij=0;sumlijseparate=0;
+			sumlij=0;sumlijseparate=0;
 			double yij[ijsize];
-			double yminusij[ncoly*nrowy-ijsize];
 			sumof2rows (l0, ntypeno,ncoly ,i,j,l0ij);
 			select2individofy ( y, nrowy, ncoly, repno, nrepno, typeno, ntypeno, i, j, yij);
 			logmarg1dataAL (yij,asint(repnosum[i-1]+repnosum[j-1]) , ncoly, combinedrepno, 1, combinedtypeno, 1, theta, l1ij);
@@ -1999,7 +1975,7 @@ void Rl1arrangeG(double *l1,int *nrowl1, int *ncoll1,
 void fastbclustG(double y[], int nrowy, int ncoly, double repno[], int nrepno, double theta[],double  *merge,double *height)
 {
 
-double typeno[nrepno], typelabel[nrepno], yclust[ncoly*nrowy], 
+double typelabel[nrepno], yclust[ncoly*nrowy], 
 	repnoclust[nrepno], typenoclust[nrepno], minvalue[1], yresult[nrowy*ncoly],
 	repnoresult[nrepno],typenoresult[nrepno],minindex[2], sumlclust=0,
 	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],lclust[nrepno*ncoly],l0result[nrepno*ncoly],
@@ -2009,7 +1985,7 @@ int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno;
 /*initialization*/
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -2104,16 +2080,16 @@ for (i=1;i<ntypeno;i++)
 
 void fastbclustvsG(double y[], int nrowy, int ncoly, double repno[], int nrepno, double theta[],double  *merge,double *height)
 {
-double typeno[nrepno], typelabel[nrepno], yclust[ncoly*nrowy], 
+double typelabel[nrepno], yclust[ncoly*nrowy], 
 	repnoclust[nrepno], typenoclust[nrepno], minvalue[1], yresult[nrowy*ncoly],
-	repnoresult[nrepno],typenoresult[nrepno],minindex[2], sumlclust=0,
-	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],lclust[nrepno*ncoly],l0result[nrepno*ncoly],
+	repnoresult[nrepno],typenoresult[nrepno],minindex[2], 
+	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],l0result[nrepno*ncoly],
 	l1result[nrepno*ncoly], typelabelresult[nrepno],suml0clust[ncoly],suml1clust[ncoly];
 int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno;
 
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -2184,16 +2160,16 @@ for (i=1;i<ntypeno;i++)
 
 void fastbclustvsAL(double y[], int nrowy, int ncoly, double repno[], int nrepno, double theta[],double  *merge,double *height)
 {
-double typeno[nrepno], typelabel[nrepno], yclust[ncoly*nrowy], 
+double  typelabel[nrepno], yclust[ncoly*nrowy], 
 	repnoclust[nrepno], typenoclust[nrepno], minvalue[1], yresult[nrowy*ncoly],
-	repnoresult[nrepno],typenoresult[nrepno],minindex[2], sumlclust=0,
-	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],lclust[nrepno*ncoly],l0result[nrepno*ncoly],
+	repnoresult[nrepno],typenoresult[nrepno],minindex[2],
+	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],l0result[nrepno*ncoly],
 	l1result[nrepno*ncoly], typelabelresult[nrepno],suml0clust[ncoly],suml1clust[ncoly];
 int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno;
 
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -2289,7 +2265,7 @@ void fastbclustAL(double y[], int nrowy, int ncoly, double repno[], int nrepno,
 /*	double *typeno = (double *) R_alloc(nrepno * sizeof(double));*/
 	
 	
-double typeno[nrepno], typelabel[nrepno], yclust[ncoly*nrowy], 
+double typelabel[nrepno], yclust[ncoly*nrowy], 
 	repnoclust[nrepno], typenoclust[nrepno], minvalue[1], yresult[nrowy*ncoly],
 	repnoresult[nrepno],typenoresult[nrepno],minindex[2], sumlclust=0,
 	l0clust[nrepno*ncoly],l1clust[nrepno*ncoly],lclust[nrepno*ncoly],l0result[nrepno*ncoly],
@@ -2299,7 +2275,7 @@ int i,j, nrepnoclust=nrepno, ntypenoclust=nrepno, ntypeno=nrepno;
 /*initialization*/
 for 	(i=0; i<nrepno;i++)
 	{
-		typeno[i]=1;
+
 		typelabel[i]=-(i+1);
 		repnoclust[i]=repno[i];
 		typenoclust [i]=1;
@@ -2506,7 +2482,7 @@ void loglikbylabelG(double y[], int nrowy, int ncoly, double repno[], int nrepno
 	double theta[], double *result)
 	{
 	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2519,7 +2495,7 @@ void loglikbylabelvsG(double y[], int nrowy, int ncoly, double repno[], int nrep
 	double theta[], double *result)
 	{
 	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2533,7 +2509,7 @@ void loglikbylabelAL(double y[], int nrowy, int ncoly, double repno[], int nrepn
 	double theta[], double *result)
 	{
 	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2546,7 +2522,7 @@ void loglikbylabelvsAL(double y[], int nrowy, int ncoly, double repno[], int nre
 	double theta[], double *result)
 	{
 	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2587,7 +2563,7 @@ void logprobabilitycalculatorG(double y[], int nrowy, int ncoly, double repno[],
 	double worklabel[nlabel];
 	int i;
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
-	int maxlab=asint(maxofvector(label,nlabel)),labelround,nhelpvec[1];
+	int maxlab=asint(maxofvector(label,nlabel)),nhelpvec[1];
 	double helpvec[nlabel];
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno],singlelogprob[1], logdirich[1];
 	int nhelptypeno[1];
@@ -2618,7 +2594,7 @@ void logprobabilitycalculatorAL(double y[], int nrowy, int ncoly, double repno[]
 	double worklabel[nlabel];
 	int i;
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
-	int maxlab=asint(maxofvector(label,nlabel)),labelround,nhelpvec[1];
+	int maxlab=asint(maxofvector(label,nlabel)),nhelpvec[1];
 	double helpvec[nlabel];
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno],singlelogprob[1], logdirich[1];
 	int nhelptypeno[1];
@@ -2640,7 +2616,7 @@ void logprobabilitycalculatorAL(double y[], int nrowy, int ncoly, double repno[]
 	}
 
 	
-
+/*
 void RlogprobabilitycalculatorG(double *y, int *nrowy, int *ncoly, double *repno, 
 	int *nrepno, double *label, int *nlabel, int *indexpos, double *theta, double *changedlabel, int *nchangedlabel, double *logprob)
 	{
@@ -2664,6 +2640,7 @@ void RlogprobabilitycalculatorG(double *y, int *nrowy, int *ncoly, double *repno
 	}
 
 	
+
 int rmultinomial (double logprob[], int nlogprob)
 	{
 		int rnd[nlogprob],i;
@@ -2672,8 +2649,8 @@ int rmultinomial (double logprob[], int nlogprob)
 		for (i=0;i<nlogprob;i++)
 			{
 			logprobadded[i]=logprob[i]-maxlogprob;
-/*			printf("\n normalized logprob of %d is %d", (i+1), (int)(logprobadded[i]));
-*/			}
+			printf("\n normalized logprob of %d is %d", (i+1), (int)(logprobadded[i]));
+			}
 
 		for (i=0;i<nlogprob;i++)
 			{
@@ -2684,8 +2661,8 @@ int rmultinomial (double logprob[], int nlogprob)
 		for (i=0;i<nlogprob;i++)
 			{
 			prob[i]=exp(logprobadded[i])/sumprob;
-/*			printf("\nI sample from %d with percent %d", (i+1), (int)(100*prob[i]));
-*/			}
+			printf("\nI sample from %d with percent %d", (i+1), (int)(100*prob[i]));
+			}
 		
 		rmultinom(1,prob,nlogprob,rnd);
 		for (i=0;i<nlogprob;i++)
@@ -2693,7 +2670,7 @@ int rmultinomial (double logprob[], int nlogprob)
 		if (rnd[i]>0) {return (i+1);}
 		}
 	}
-
+*/
 		
 	
 void relabel(double label[], int nlabel,double *result)
@@ -2717,6 +2694,7 @@ void relabel(double label[], int nlabel,double *result)
 	}
 	
 
+/*
 void RmcmcG(double *y, int *nrowy, int *ncoly, double *repno, 
 	int *nrepno, double *label, int *nlabel, double *theta, int *mciter,double *result)
 	{
@@ -2727,12 +2705,12 @@ void RmcmcG(double *y, int *nrowy, int *ncoly, double *repno,
 		randpermute(*nrepno, randindex);
 		for (j=0;j<*nrepno;j++)
 			{
-/*			printf("\n\ncurrent label is\n");
+			printf("\n\ncurrent label is\n");
 			for (k=0;k<*nrepno;k++)
 				{
 				printf("  %d  ",(int)label[k]);
 				}
-*/			logprobabilitycalculatorG(y, *nrowy, *ncoly, repno, *nrepno, label, *nlabel, randindex[j], 
+			logprobabilitycalculatorG(y, *nrowy, *ncoly, repno, *nrepno, label, *nlabel, randindex[j], 
 				theta, changedlabel, nchangedlabel, logprob);
 			sumprob=0;
 			for (k=1;k<nchangedlabel[0];k++)
@@ -2743,14 +2721,14 @@ void RmcmcG(double *y, int *nrowy, int *ncoly, double *repno,
 				{
 					prob[k-1]=exp(logprob[k-1])/sumprob;
 				}
-/*			for (k=1;k<=nchangedlabel[0];k++)
+			for (k=1;k<=nchangedlabel[0];k++)
 				{
 				printf("\n position %d can get %d with logprobability %d",randindex[j], k, (int)(logprob[k-1]) );
 				}
-*/			
+			
 			mysample=rmultinomial(logprob,nchangedlabel[0]);
-/*			printf("\nmysample for position %d is  %d had logprob %d \n",randindex[j], mysample, (int)logprob[(mysample-1)] );
-*/			
+			printf("\nmysample for position %d is  %d had logprob %d \n",randindex[j], mysample, (int)logprob[(mysample-1)] );
+
 			label[randindex[j]-1]=mysample;
 			relabel(label,*nlabel ,helplabel);
 			for (k=0;k<*nrepno;k++)
@@ -2763,7 +2741,7 @@ void RmcmcG(double *y, int *nrowy, int *ncoly, double *repno,
 		}
 	}
 
-	
+*/				
 	
 	
 	
@@ -2780,7 +2758,7 @@ void RmcmcG(double *y, int *nrowy, int *ncoly, double *repno,
 
 
 
-
+/*
 void RmcmcAL(double *y, int *nrowy, int *ncoly, double *repno, 
 	int *nrepno, double *label, int *nlabel, double *theta, int *mciter,double *result)
 	{
@@ -2791,12 +2769,12 @@ void RmcmcAL(double *y, int *nrowy, int *ncoly, double *repno,
 		randpermute(*nrepno, randindex);
 		for (j=0;j<*nrepno;j++)
 			{
-/*			printf("\n\ncurrent label is\n");
+			printf("\n\ncurrent label is\n");
 			for (k=0;k<*nrepno;k++)
 				{
 				printf("  %d  ",(int)label[k]);
 				}
-*/			logprobabilitycalculatorAL(y, *nrowy, *ncoly, repno, *nrepno, label, *nlabel, randindex[j], 
+			logprobabilitycalculatorAL(y, *nrowy, *ncoly, repno, *nrepno, label, *nlabel, randindex[j], 
 				theta, changedlabel, nchangedlabel, logprob);
 			sumprob=0;
 			for (k=1;k<nchangedlabel[0];k++)
@@ -2807,14 +2785,14 @@ void RmcmcAL(double *y, int *nrowy, int *ncoly, double *repno,
 				{
 					prob[k-1]=exp(logprob[k-1])/sumprob;
 				}
-/*			for (k=1;k<=nchangedlabel[0];k++)
+			for (k=1;k<=nchangedlabel[0];k++)
 				{
 				printf("\n position %d can get %d with logprobability %d",randindex[j], k, (int)(logprob[k-1]) );
 				}
-*/			
+			
 			mysample=rmultinomial(logprob,nchangedlabel[0]);
-/*			printf("\nmysample for position %d is  %d had logprob %d \n",randindex[j], mysample, (int)logprob[(mysample-1)] );
-*/			
+			printf("\nmysample for position %d is  %d had logprob %d \n",randindex[j], mysample, (int)logprob[(mysample-1)] );
+			
 			label[randindex[j]-1]=mysample;
 			relabel(label,*nlabel ,helplabel);
 			for (k=0;k<*nrepno;k++)
@@ -2827,7 +2805,7 @@ void RmcmcAL(double *y, int *nrowy, int *ncoly, double *repno,
 		}
 	}
 
-
+*/
 
 
 
@@ -2838,21 +2816,10 @@ void RmcmcAL(double *y, int *nrowy, int *ncoly, double *repno,
 	
 	
 	
-	/*	printf("\n Label \n");
-	for (i=0;i<*nrepno;i++)
-		{
-		printf(" %d ",(int)label[i]);
-		}
-		printf("\n ReLabel \n");
-	for (i=0;i<*nrepno;i++)
-		{
-		printf(" %d ",(int)helplabel[i]);
-		}*/
-/*	printf( "\n");*/
-
 
 
 
+/*
 void Rrmultinomial (double *logprob,int *nlogprob,int *result)
 	{
 	int i;
@@ -2862,6 +2829,7 @@ void Rrmultinomial (double *logprob,int *nlogprob,int *result)
 		result[i]=rmultinomial(logprob,*nlogprob);
 		}
 	}
+*/
 	
 void Rrelabel( double *label, int *nlabel,double *result)
 {
@@ -2873,8 +2841,8 @@ void Rrelabel( double *label, int *nlabel,double *result)
 void loglikbylabelGunif(double y[], int nrowy, int ncoly, double repno[], int nrepno, double label[], int nlabel,
 	double theta[], double *result)
 	{
-	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	double worklabel[nlabel],resultnodirich[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2892,8 +2860,8 @@ void RloglikbylabelGunif(double *y,int *nrowy,int *ncoly,double *repno,int *nrep
 void loglikbylabelALunif(double y[], int nrowy, int ncoly, double repno[], int nrepno, double label[], int nlabel,
 	double theta[], double *result)
 	{
-	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	double worklabel[nlabel],resultnodirich[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2913,8 +2881,8 @@ void RloglikbylabelALunif(double *y,int *nrowy,int *ncoly,double *repno,int *nre
 void loglikbylabelvsGunif(double y[], int nrowy, int ncoly, double repno[], int nrepno, double label[], int nlabel,
 	double theta[], double *result)
 	{
-	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	double worklabel[nlabel],resultnodirich[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
@@ -2933,8 +2901,8 @@ void RloglikbylabelvsGunif(double *y,int *nrowy,int *ncoly,double *repno,int *nr
 void loglikbylabelvsALunif(double y[], int nrowy, int ncoly, double repno[], int nrepno, double label[], int nlabel,
 	double theta[], double *result)
 	{
-	double worklabel[nlabel],logdirich[1],resultnodirich[1];
-	int i,nhelpno,nhelptypeno[1];
+	double worklabel[nlabel],resultnodirich[1];
+	int i,nhelptypeno[1];
 	for (i=0;i<nlabel;i++){worklabel[i]=label[i];}
 	double helpy[ncoly*nrowy], helprepno[nrepno], helptypeno[nrepno];
 	yarrangebylabel (y, nrowy, ncoly, repno, nrepno, worklabel, nlabel,helpy, helprepno, helptypeno, nhelptypeno);
